summaryrefslogtreecommitdiffstats
path: root/src/kmplayer_smil.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:14 -0600
commitee4b31b7bd3e899cad30866bf083c3ff6a4a9fc8 (patch)
tree0630bc6a5a0e9a1187503dca93799ee21055d050 /src/kmplayer_smil.h
parentf97c8a56e217f04e08776ccf8021721b7d919b7d (diff)
downloadkmplayer-ee4b31b7bd3e899cad30866bf083c3ff6a4a9fc8.tar.gz
kmplayer-ee4b31b7bd3e899cad30866bf083c3ff6a4a9fc8.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit f97c8a56e217f04e08776ccf8021721b7d919b7d.
Diffstat (limited to 'src/kmplayer_smil.h')
-rw-r--r--src/kmplayer_smil.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/kmplayer_smil.h b/src/kmplayer_smil.h
index 0629c60..5392101 100644
--- a/src/kmplayer_smil.h
+++ b/src/kmplayer_smil.h
@@ -61,7 +61,7 @@ class TextRuntimePrivate;
/*
* Event signaled before the actual starting takes place. Use by SMIL::Excl
- * to stop possible other children
+ * to stop possible other tqchildren
*/
class ToBeStartedEvent : public Event {
public:
@@ -215,7 +215,7 @@ protected:
virtual void remoteReady (TQByteArray &);
private slots:
void movieUpdated (const TQRect &);
- void movieStatus (int);
+ void movietqStatus (int);
void movieResize (const TQSize &);
};
@@ -444,15 +444,15 @@ public:
/**
* repaints region, calls scheduleRepaint(x,y,w,h) on view
*/
- void repaint ();
- void repaint (const SRect & rect);
+ void tqrepaint ();
+ void tqrepaint (const SRect & rect);
/**
* calculate the relative x,y,w,h on the child region elements
* given this element's w and h value
* and child's left/top/right/width/height/bottom attributes
*/
virtual void updateDimensions ();
- void boundsUpdate (); // recalculates and repaint old and new bounds
+ void boundsUpdate (); // recalculates and tqrepaint old and new bounds
virtual Surface *surface ();
SurfacePtrW region_surface;
@@ -471,13 +471,13 @@ protected:
};
/**
* Defines region layout, should reside below 'head' element
*/
class KMPLAYER_NO_EXPORT Layout : public RegionBase {
public:
Layout (NodePtr & d);
NodePtr childFromTag (const TQString & tag);
- KDE_NO_EXPORT const char * nodeName () const { return "layout"; }
+ KDE_NO_EXPORT const char * nodeName () const { return "tqlayout"; }
void activate ();
void closed ();
virtual void accept (Visitor *);
@@ -517,11 +517,11 @@ class KMPLAYER_NO_EXPORT RootLayout : public RegionBase {
public:
KDE_NO_CDTOR_EXPORT RootLayout (NodePtr & d)
: RegionBase (d, id_node_root_layout) {}
- KDE_NO_EXPORT const char * nodeName () const { return "root-layout"; }
+ KDE_NO_EXPORT const char * nodeName () const { return "root-tqlayout"; }
};
/**
- * Represents a regPoint element for alignment inside regions
+ * Represents a regPoint element for tqalignment inside regions
*/
class KMPLAYER_NO_EXPORT RegPoint : public Element {
public:
@@ -656,7 +656,7 @@ protected:
};
/**
- * A Par represents parallel processing of all its children
+ * A Par represents parallel processing of all its tqchildren
*/
class KMPLAYER_NO_EXPORT Par : public GroupBase {
public:
@@ -668,7 +668,7 @@ public:
};
/**
- * A Seq represents sequential processing of all its children
+ * A Seq represents sequential processing of all its tqchildren
*/
class KMPLAYER_NO_EXPORT Seq : public GroupBase {
public:
@@ -691,7 +691,7 @@ public:
};
/**
- * An Excl represents exclusive processing of one of its children
+ * An Excl represents exclusive processing of one of its tqchildren
*/
class KMPLAYER_NO_EXPORT Excl : public GroupBase {
public:
@@ -780,7 +780,7 @@ public:
Surface *surface ();
void resetSurface ();
SRect calculateBounds ();
- void boundsUpdate (); // recalculates and repaint old and new bounds
+ void boundsUpdate (); // recalculates and tqrepaint old and new bounds
virtual void parseParam (const TrieString & name, const TQString & value);
virtual bool handleEvent (EventPtr event);
NodeRefListPtr listeners (unsigned int event_id);
@@ -471,13 +471,13 @@ protected:
};
/**
- * Defines region layout, should reside below 'head' element
+ * Defines region tqlayout, should reside below 'head' element
*/
class KMPLAYER_NO_EXPORT Layout : public RegionBase {